#ifndef _X11_CONSTRAINT_H_
#define _X11_CONSTRAINT_H_

#include <X11/Intrinsic.h>
#include <X11/CompositeP.h>
#include <X11/ConstrainP.h>

#ifdef __cplusplus
extern "C" {
#endif




    typedef struct _ConstraintClassRec *ConstraintWidgetClass;


    extern WidgetClass constraintWidgetClass;
#ifdef __cplusplus
}
#endif
#endif
